@@ -36,6 +36,7 @@
 
 #include <math.h>
 #include <stdint.h>
+#include <stdlib.h>
 
 #include <list>
 #include <vector>
@@ -1068,6 +1069,9 @@ class Model
       void setCanvasDrawMode( int m ) { m_canvasDrawMode = m; };
       int  getCanvasDrawMode() const { return m_canvasDrawMode; };
 
+      void setPerspectiveDrawMode( int m ) { m_perspectiveDrawMode = m; };
+      int  getPerspectiveDrawMode() const { return m_perspectiveDrawMode; };
+
       void setDrawJoints( DrawJointModeE m ) { m_drawJoints = m; };
       DrawJointModeE getDrawJoints() const { return m_drawJoints; };
 
@@ -1335,6 +1339,11 @@ class Model
       Material::MaterialTypeE getMaterialType( unsigned materialIndex ) const;
       int getMaterialColor( unsigned materialIndex, unsigned c, unsigned v = 0 ) const;
 
+      int removeUnusedGroups();
+      int mergeIdenticalGroups();
+      int removeUnusedMaterials();
+      int mergeIdenticalMaterials();
+
       // These implicitly change the material type.
       void setMaterialTexture( unsigned textureId, Texture * tex );
       void removeMaterialTexture( unsigned textureId );
@@ -1685,6 +1694,10 @@ class Model
       // like a manual analog to the deleteOrphanedVertices() function).
       void selectFreeVertices();
 
+      void setSelectedUv( const vector<int> & uvList );
+      void getSelectedUv( vector<int> & uvList ) const;
+      void clearSelectedUv();
+
       // ------------------------------------------------------------------
       // Hide functions
       // ------------------------------------------------------------------
@@ -1843,6 +1856,7 @@ class Model
       vector<FormatData *>  m_formatData;
 
       int  m_canvasDrawMode;
+      int  m_perspectiveDrawMode;
       DrawJointModeE m_drawJoints;
       bool m_drawProjections;
 
@@ -1860,6 +1874,7 @@ class Model
       double   m_currentTime;
 
 #ifdef MM3D_EDIT
+      vector<int> m_selectedUv;
 
       ObserverList m_observers;
 
